#
# spec file for package hourglass
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hourglass
Version:        2.0.2
Release:        bp155.1.5
Summary:        Clock gadget for Elementary OS
License:        GPL-3.0-only
Group:          System/X11/Utilities
URL:            https://github.com/sgpthomas
Source:         https://github.com/sgpthomas/hourglass/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite) >= 6.0.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libnotify)
Recommends:     %{name}-lang

%description
A clock application that is designed to fit perfectly into
Elementary's design scheme.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.sgpthomas.hourglass GTK Utility Clock
%find_lang com.github.sgpthomas.hourglass %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/com.github.sgpthomas.hourglass
%{_bindir}/com.github.sgpthomas.hourglass-daemon
%{_datadir}/applications/com.github.sgpthomas.hourglass.desktop
%{_datadir}/glib-2.0/schemas/com.github.sgpthomas.hourglass.gschema.xml
%{_datadir}/icons/hicolor/*/*/com.github.sgpthomas.hourglass.??g
%{_datadir}/metainfo/com.github.sgpthomas.hourglass.appdata.xml
%{_datadir}/pixmaps/com.github.sgpthomas.hourglass.??g
%{_sysconfdir}/xdg/autostart/com.github.sgpthomas.hourglass-daemon.desktop

%files lang -f %{name}.lang

%changelog
* Sat Nov 20 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.2:
  * Fix a regression that the app don't launch if you create a
    repeated alarm, close the app, and try to reopen it
  * AlarmView: Organize displayed information
- This release contains small bug fixes and improvements:
  * Strict on sandbox permission
  * Rounded window corners and flat titlebar
  * NewAlarmDialog: Add placeholder text for title entry
  * Set shorter summary text in appdata
  * Use palette of elementary for branding color
  * Make sure to select an alarm on removing/adding/editing it
    and startup
  * Clean code
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.0:
  * This release comes with numerous bug fixes &amp;
    improvements!
- Changes in Alarm:
  * Refresh weekday toggle activity when opening popover
  * Notify on every 0 second
  * Keep repeated alarms on and turn off one-time alarms after
    ringing
  * Now alarm date is optional; if you don't specify date of the
    alarm, it will be notified at that time of today
  * Remove unused "update-frequency" gsettings key
  * Fix repeating alarms can't be disabled
  * Explicitly set the year
- Changes in Timer:
  * Add Reset button
  * Support setting purpose of a timer
  * Lessen damages to your storage
  * Restore started time on end
  * Make sure to iconify always when the timer is active
- Other changes:
  * Fix a regression that any key input no longer accepted
  * Lessen window width by default
  * Fix the app exits if the window has been iconified
  * Code refactoring
  * Update translations
  * Publish the app to the new AppCenter on elementary OS 6 with
    the Flatpak manifest
  * Respect an elementary OS-wide dark preference
  * Now you can close the window with the shortcut key Ctrl+Q,
    while the daemon stays running in the background
  * Fix unreadable font size in the Alarm view
  * Fix wrong OARS data
  * Move the delete button in the action bar
  * Redesign app icons (big thanks to @Fatih20)
  * Update Brazilian Portuguese translation (by @gfavaro)
* Sun Oct 11 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.3:
  * StopWatch: Rewrite for efficiency and visibility
  * Add :disabled pseudo-class to the .round-button class
  * Fix a fatal regression that timer does not stop on 00:00:00
  * Use icons for add/remove buttons
  * Update .desktop comment to be consistent with HIG (by
    @aljelly)
  * Change shortened format of weekdays (by @NathanBnm)
  * Improve look of create/edit alarm dialog
  * Don't reset repeat setting on closing popover
  * Fix DBus error at the first launch
  * Fix notification icon is not set
  * Fix left time shows unexpected values if set time is too big
  * Improve saving window state
  * Add French translation (by @NathanBnm)
  * Update Spanish translation (by @CCaroV)
  * Add Japanese translation
  * Add Portuguese-Portugal translation (by @rottenpants466)
  * Various l10n and coding improvements to the project thanks to
    @NathanBnm
* Thu Apr 30 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.1:
  * Merge pull request #58 from ryonakano/add-meson
  * Remove no longer used config data element
  * Use GResource to load CSS
  * README: Add installation instruction
  * Tweak line breaks
  * DRY meson project name
  * Remove unnecessary files
  * Remove overkilling or unnecessary configs/files
  * Complete RDNN
  * Revert unwanted change
  * Tab to 4 spaces
  * Add meson
  * fixed the notification going off again when you open the app
  * Merge branch 'master' of github.com:sgpthomas/hourglass
  * fixed what happens when the app closes and there is a timer
    running
  * Merge pull request #45 from danrabbit/patch-1
  * Remove "." from appdata summary
  * Merge pull request #41 from Allen-B1/patch-1
  * Add the Get it on AppCenter button
  * hourglass finally knows how to keep time, closes #34
  * Merge pull request #39 from welaq/master
  * Added Lithuanian to .desktop
  * Added Lithuanian comment
  * fixed #35 by disallowing multiple windows
- Switch to meson
- Spec file cleanup
* Fri Nov 10 2017 avvissu@yandex.by
- Update to 1.1.1:
  * Made the alarm noise persist until you close the notification
  * Added some margin to the repeat day label
- Switch from bzr to git
- Add AppData file
- Spec file cleanup
* Tue Jun 13 2017 jengelh@inai.de
- Ensure neutrality of description.
* Wed May 10 2017 avvissu@yandex.by
- Update to stable release 1.0.1
- Specfile cleanup
* Sun Mar  6 2016 and.november@opensuse.org
- initial package (version 1.0.1) for openSUSE
